@@ -119,13 +119,13 @@ mod tests {
     use crate::test;
     use twilight_model::{
         channel::{Reaction, ReactionType},
-        id::{ChannelId, GuildId, MessageId, UserId},
+        id::Id,
     };
 
     #[test]
     fn test_reaction_add() {
         let cache = test::cache_with_message_and_reactions();
-        let msg = cache.message(MessageId::new(4).expect("non zero")).unwrap();
+        let msg = cache.message(Id::new(4)).unwrap();
 
         assert_eq!(msg.reactions.len(), 2);
 
@@ -148,17 +148,17 @@ mod tests {
     fn test_reaction_remove() {
         let cache = test::cache_with_message_and_reactions();
         cache.update(&ReactionRemove(Reaction {
-            channel_id: ChannelId::new(2).expect("non zero"),
+            channel_id: Id::new(2),
             emoji: ReactionType::Unicode {
                 name: "😀".to_owned(),
             },
-            guild_id: Some(GuildId::new(1).expect("non zero")),
+            guild_id: Some(Id::new(1)),
             member: None,
-            message_id: MessageId::new(4).expect("non zero"),
-            user_id: UserId::new(5).expect("non zero"),
+            message_id: Id::new(4),
+            user_id: Id::new(5),
         }));
 
-        let msg = cache.message(MessageId::new(4).expect("non zero")).unwrap();
+        let msg = cache.message(Id::new(4)).unwrap();
 
         assert_eq!(msg.reactions.len(), 2);
 
@@ -181,12 +181,12 @@ mod tests {
     fn test_reaction_remove_all() {
         let cache = test::cache_with_message_and_reactions();
         cache.update(&ReactionRemoveAll {
-            channel_id: ChannelId::new(2).expect("non zero"),
-            message_id: MessageId::new(4).expect("non zero"),
-            guild_id: Some(GuildId::new(1).expect("non zero")),
+            channel_id: Id::new(2),
+            message_id: Id::new(4),
+            guild_id: Some(Id::new(1)),
         });
 
-        let msg = cache.message(MessageId::new(4).expect("non zero")).unwrap();
+        let msg = cache.message(Id::new(4)).unwrap();
 
         assert_eq!(msg.reactions.len(), 0);
     }
@@ -195,15 +195,15 @@ mod tests {
     fn test_reaction_remove_emoji() {
         let cache = test::cache_with_message_and_reactions();
         cache.update(&ReactionRemoveEmoji {
-            channel_id: ChannelId::new(2).expect("non zero"),
+            channel_id: Id::new(2),
             emoji: ReactionType::Unicode {
                 name: "😀".to_owned(),
             },
-            guild_id: GuildId::new(1).expect("non zero"),
-            message_id: MessageId::new(4).expect("non zero"),
+            guild_id: Id::new(1),
+            message_id: Id::new(4),
         });
 
-        let msg = cache.message(MessageId::new(4).expect("non zero")).unwrap();
+        let msg = cache.message(Id::new(4)).unwrap();
 
         assert_eq!(msg.reactions.len(), 1);
 
