@@ -22,9 +22,15 @@ use dashmap::{
 };
 use std::{collections::VecDeque, hash::Hash, ops::Deref};
 use twilight_model::{
-    channel::{message::sticker::StickerId, Group, GuildChannel, PrivateChannel, StageInstance},
+    channel::{Group, GuildChannel, PrivateChannel, StageInstance},
     guild::{GuildIntegration, Role},
-    id::{ChannelId, EmojiId, GuildId, IntegrationId, MessageId, RoleId, StageId, UserId},
+    id::{
+        marker::{
+            ChannelMarker, EmojiMarker, GuildMarker, IntegrationMarker, MessageMarker, RoleMarker,
+            StageMarker, StickerMarker, UserMarker,
+        },
+        Id,
+    },
     user::User,
     voice::VoiceState,
 };
@@ -104,12 +110,12 @@ impl<K: Eq + Hash, V> Deref for IterReference<'_, K, V> {
 ///
 /// ```no_run
 /// use twilight_cache_inmemory::InMemoryCache;
-/// use twilight_model::id::GuildId;
+/// use twilight_model::id::Id;
 ///
 /// let cache = InMemoryCache::new();
 ///
 /// // later in the application...
-/// let guild_id = GuildId::new(1).expect("non zero id");
+/// let guild_id = Id::new(1);
 /// let maybe_guild_members = cache.guild_members(guild_id);
 ///
 /// if let Some(guild_members) = maybe_guild_members {
@@ -139,17 +145,17 @@ impl<'a> InMemoryCacheIter<'a> {
     }
 
     /// Create an iterator over the emojis in the cache.
-    pub fn emojis(&self) -> ResourceIter<'a, EmojiId, GuildResource<CachedEmoji>> {
+    pub fn emojis(&self) -> ResourceIter<'a, Id<EmojiMarker>, GuildResource<CachedEmoji>> {
         ResourceIter::new(self.0.emojis.iter())
     }
 
     /// Create an iterator over the groups in the cache.
-    pub fn groups(&self) -> ResourceIter<'a, ChannelId, Group> {
+    pub fn groups(&self) -> ResourceIter<'a, Id<ChannelMarker>, Group> {
         ResourceIter::new(self.0.groups.iter())
     }
 
     /// Create an iterator over the guilds in the cache.
-    pub fn guilds(&self) -> ResourceIter<'a, GuildId, CachedGuild> {
+    pub fn guilds(&self) -> ResourceIter<'a, Id<GuildMarker>, CachedGuild> {
         ResourceIter::new(self.0.guilds.iter())
     }
 
@@ -157,59 +163,64 @@ impl<'a> InMemoryCacheIter<'a> {
     ///
     /// This does *not* iterate over the channels in a particular guild but
     /// rather iterates over all [`GuildChannel`]s in the cache.
-    pub fn guild_channels(&self) -> ResourceIter<'a, ChannelId, GuildResource<GuildChannel>> {
+    pub fn guild_channels(
+        &self,
+    ) -> ResourceIter<'a, Id<ChannelMarker>, GuildResource<GuildChannel>> {
         ResourceIter::new(self.0.channels_guild.iter())
     }
 
     /// Create an iterator over the integrations in the cache.
     pub fn integrations(
         &self,
-    ) -> ResourceIter<'a, (GuildId, IntegrationId), GuildResource<GuildIntegration>> {
+    ) -> ResourceIter<'a, (Id<GuildMarker>, Id<IntegrationMarker>), GuildResource<GuildIntegration>>
+    {
         ResourceIter::new(self.0.integrations.iter())
     }
 
     /// Create an iterator over the members across all guilds in the cache.
-    pub fn members(&self) -> ResourceIter<'a, (GuildId, UserId), CachedMember> {
+    pub fn members(&self) -> ResourceIter<'a, (Id<GuildMarker>, Id<UserMarker>), CachedMember> {
         ResourceIter::new(self.0.members.iter())
     }
 
     /// Create an iterator over the messages in the cache.
-    pub fn messages(&self) -> ResourceIter<'a, MessageId, CachedMessage> {
+    pub fn messages(&self) -> ResourceIter<'a, Id<MessageMarker>, CachedMessage> {
         ResourceIter::new(self.0.messages.iter())
     }
 
     /// Create an iterator over the presences in the cache.
-    pub fn presences(&self) -> ResourceIter<'a, (GuildId, UserId), CachedPresence> {
+    pub fn presences(&self) -> ResourceIter<'a, (Id<GuildMarker>, Id<UserMarker>), CachedPresence> {
         ResourceIter::new(self.0.presences.iter())
     }
 
     /// Create an iterator over the private channels in the cache.
-    pub fn private_channels(&self) -> ResourceIter<'a, ChannelId, PrivateChannel> {
+    pub fn private_channels(&self) -> ResourceIter<'a, Id<ChannelMarker>, PrivateChannel> {
         ResourceIter::new(self.0.channels_private.iter())
     }
 
     /// Create an iterator over the roles in the cache.
-    pub fn roles(&self) -> ResourceIter<'a, RoleId, GuildResource<Role>> {
+    pub fn roles(&self) -> ResourceIter<'a, Id<RoleMarker>, GuildResource<Role>> {
         ResourceIter::new(self.0.roles.iter())
     }
 
     /// Create an iterator over the stage instances in the cache.
-    pub fn stage_instances(&self) -> ResourceIter<'a, StageId, GuildResource<StageInstance>> {
+    pub fn stage_instances(
+        &self,
+    ) -> ResourceIter<'a, Id<StageMarker>, GuildResource<StageInstance>> {
         ResourceIter::new(self.0.stage_instances.iter())
     }
 
     /// Create an iterator over the stickers in the cache.
-    pub fn stickers(&self) -> ResourceIter<'a, StickerId, GuildResource<CachedSticker>> {
+    pub fn stickers(&self) -> ResourceIter<'a, Id<StickerMarker>, GuildResource<CachedSticker>> {
         ResourceIter::new(self.0.stickers.iter())
     }
 
     /// Create an iterator over the users in the cache.
-    pub fn users(&self) -> ResourceIter<'a, UserId, User> {
+    pub fn users(&self) -> ResourceIter<'a, Id<UserMarker>, User> {
         ResourceIter::new(self.0.users.iter())
     }
 
     /// Create an iterator over the voice states in the cache.
-    pub fn voice_states(&self) -> ResourceIter<'a, (GuildId, UserId), VoiceState> {
+    pub fn voice_states(&self) -> ResourceIter<'a, (Id<GuildMarker>, Id<UserMarker>), VoiceState> {
         ResourceIter::new(self.0.voice_states.iter())
     }
 }
@@ -268,7 +279,7 @@ impl<'a, K: Eq + Hash, V> Iterator for ResourceIter<'a, K, V> {
 /// use twilight_cache_inmemory::InMemoryCache;
 /// use twilight_model::id::{ChannelId, MessageId};
 ///
-/// let channel_id = ChannelId::new(1).expect("non zero id");
+/// let channel_id = ChannelId::new(1);
 ///
 /// let cache = InMemoryCache::new();
 /// let message_ids = cache.channel_messages(channel_id)?;
@@ -286,11 +297,13 @@ impl<'a, K: Eq + Hash, V> Iterator for ResourceIter<'a, K, V> {
 /// ```
 pub struct ChannelMessages<'a> {
     index: usize,
-    message_ids: Ref<'a, ChannelId, VecDeque<MessageId>>,
+    message_ids: Ref<'a, Id<ChannelMarker>, VecDeque<Id<MessageMarker>>>,
 }
 
 impl<'a> ChannelMessages<'a> {
-    pub(super) const fn new(message_ids: Ref<'a, ChannelId, VecDeque<MessageId>>) -> Self {
+    pub(super) const fn new(
+        message_ids: Ref<'a, Id<ChannelMarker>, VecDeque<Id<MessageMarker>>>,
+    ) -> Self {
         Self {
             index: 0,
             message_ids,
@@ -299,7 +312,7 @@ impl<'a> ChannelMessages<'a> {
 }
 
 impl<'a> Iterator for ChannelMessages<'a> {
-    type Item = MessageId;
+    type Item = Id<MessageMarker>;
 
     fn next(&mut self) -> Option<Self::Item> {
         if let Some(message_id) = self.message_ids.get(self.index) {
@@ -325,22 +338,22 @@ mod tests {
     use static_assertions::assert_impl_all;
     use std::{borrow::Cow, fmt::Debug};
     use twilight_model::{
-        id::{GuildId, UserId},
+        id::{marker::UserMarker, Id},
         user::User,
     };
 
     assert_impl_all!(ChannelMessages<'_>: Iterator, Send, Sync);
     assert_impl_all!(InMemoryCacheIter<'_>: Debug, Send, Sync);
-    assert_impl_all!(IterReference<'_, UserId, User>: Send, Sync);
-    assert_impl_all!(ResourceIter<'_, UserId, User>: Iterator, Send, Sync);
+    assert_impl_all!(IterReference<'_, Id<UserMarker>, User>: Send, Sync);
+    assert_impl_all!(ResourceIter<'_, Id<UserMarker>, User>: Iterator, Send, Sync);
 
     #[test]
     fn test_iter() {
-        let guild_id = GuildId::new(1).expect("non zero");
+        let guild_id = Id::new(1);
         let users = &[
-            (UserId::new(2).expect("non zero"), Some(guild_id)),
-            (UserId::new(3).expect("non zero"), Some(guild_id)),
-            (UserId::new(4).expect("non zero"), None),
+            (Id::new(2), Some(guild_id)),
+            (Id::new(3), Some(guild_id)),
+            (Id::new(4), None),
         ];
         let cache = InMemoryCache::new();
 
