@@ -6,7 +6,11 @@ use twilight_model::{
     },
     datetime::Timestamp,
     gateway::payload::incoming::{MessageCreate, ReactionAdd},
-    guild::{Emoji, Member, PartialMember, Permissions, Role},
+    guild::{
+        DefaultMessageNotificationLevel, Emoji, ExplicitContentFilter, Guild, Member, MfaLevel,
+        NSFWLevel, PartialMember, Permissions, PremiumTier, Role, SystemChannelFlags,
+        VerificationLevel,
+    },
     id::{
         marker::{ChannelMarker, EmojiMarker, GuildMarker, RoleMarker, UserMarker},
         Id,
@@ -300,3 +304,55 @@ pub fn user(id: Id<UserMarker>) -> User {
         verified: None,
     }
 }
+
+pub fn guild(id: Id<GuildMarker>, member_count: Option<u64>) -> Guild {
+    Guild {
+        afk_channel_id: None,
+        afk_timeout: 0,
+        application_id: None,
+        approximate_member_count: None,
+        approximate_presence_count: None,
+        banner: None,
+        channels: Vec::new(),
+        default_message_notifications: DefaultMessageNotificationLevel::Mentions,
+        description: None,
+        discovery_splash: None,
+        emojis: Vec::new(),
+        explicit_content_filter: ExplicitContentFilter::None,
+        features: Vec::new(),
+        icon: None,
+        id,
+        joined_at: None,
+        large: false,
+        max_members: None,
+        max_presences: None,
+        max_video_channel_users: None,
+        member_count,
+        members: Vec::new(),
+        mfa_level: MfaLevel::None,
+        name: "test".to_owned(),
+        nsfw_level: NSFWLevel::Default,
+        owner_id: Id::new(1),
+        owner: None,
+        permissions: None,
+        preferred_locale: "en_us".to_owned(),
+        premium_progress_bar_enabled: false,
+        premium_subscription_count: None,
+        premium_tier: PremiumTier::None,
+        presences: Vec::new(),
+        roles: Vec::new(),
+        rules_channel_id: None,
+        splash: None,
+        stage_instances: Vec::new(),
+        stickers: Vec::new(),
+        system_channel_flags: SystemChannelFlags::empty(),
+        system_channel_id: None,
+        threads: Vec::new(),
+        unavailable: false,
+        vanity_url_code: None,
+        verification_level: VerificationLevel::VeryHigh,
+        voice_states: Vec::new(),
+        widget_channel_id: None,
+        widget_enabled: None,
+    }
+}
